@@ -24,7 +24,7 @@ package Net::Patricia;
 use strict;
 use warnings;
 
-require 5.6.0;
+require 5.006_000;
 
 use version;
 use Carp;
@@ -39,7 +39,7 @@ BEGIN {
   @EXPORT = qw(AF_INET AF_INET6);
 }
 
-'$Revision: 1.15_06 $' =~ m/(\d+)\.(\d+)(_\d+|)/ && ( $VERSION = "$1.$2$3");
+'$Revision: 1.15_07 $' =~ m/(\d+)\.(\d+)(_\d+|)/ && ( $VERSION = "$1.$2$3");
 
 bootstrap Net::Patricia $VERSION;
 
